@@ -29,15 +29,14 @@
 #include "ui.h"
 #include "sid_test.h"
 
-enum
-  {
-    LOADER_LIST_SONG_NAME,
-    LOADER_LIST_SONG_URI,
-    LOADER_LIST_SONG_SHORT_URI,
-    LOADER_LIST_NUM_COLS
-  };
+enum {
+  LOADER_LIST_SONG_NAME,
+  LOADER_LIST_SONG_URI,
+  LOADER_LIST_SONG_SHORT_URI,
+  LOADER_LIST_NUM_COLS
+};
 
-GtkWidget * create_loader_page (msid_search_plugin *plugin,
-				void (*status_text_func) (const char*, const char*));
+GtkWidget *create_loader_page(msid_search_plugin *plugin,
+			      void (*status_text_func) (const char*, const char*));
 
 #endif
