@@ -180,7 +180,7 @@ add_song_to_playlist (const gchar *path)
 		       -1, NULL)) {
     // better this than nothing||crashes
     if (strlen (info.authorString) > strlen ("unknown"))
-      sprintf (info.authorString, "unknown\0");
+      sprintf (info.authorString, "unknown");
     else {
       return FALSE;
     }
